.. _dev-guide:

Information for developers
**************************

Unit tests
==========

For running all the unit tests and avoiding bugs, please simply run from the
main folder::

    python TESTS/unitTests.py

If all the tests pass, then you might be able to submit your Pull Request as explained
in the next section!

Proposing a Pull Request(PR)
============================

Each PR must be documented using docstings and must run the unit
tests. If you are adding new functionality, add a new test to
`unitTests.py` and provide an example.
